#!/bin/bash

# 颜色
RED="\e[31m"
GREEN="\e[32m"
RESET="\e[0m"

# 参数
export compartment_id=""                    # 租户OCID
export group_name="Core-Admins"             # 组名称
export group_des="Core-Admins"              # 组描述
export policy_name="Core-Admins"            # 策略名称
export policy_des="Core-Admins"             # 策略描述
export policy_file="file://statements.json" # 策略语句文件
export user_name="Core-Admin"               # 用户名称
export user_des="Core-Admin"                # 用户描述
export user_email="xxxxxx@x.com"            # 用户邮箱，当type为new时必填
export type="new"                           # 控制面板类型，sso、oci填old，idcs填new
export ignore_error="0"                     # 忽略错误

# 检查参数
if [ "$type" == "new" ]; then
  if [ "$user_email" == "" ]; then
    echo -e "${RED}用户邮箱不能为空${RESET}"
    exit 1
  fi
fi

# 策略语句
if [ "$type" == "new" ]; then
  echo "[
    \"Allow group 'Default'/'$group_name' to manage instance-family in tenancy\",
    \"Allow group 'Default'/'$group_name' to manage volume-family in tenancy\",
    \"Allow group 'Default'/'$group_name' to manage virtual-network-family in tenancy\"
  ]" > statements.json
else 
  echo "[
    \"Allow group $group_name to manage instance-family in tenancy\",
    \"Allow group $group_name to manage volume-family in tenancy\",
    \"Allow group $group_name to manage virtual-network-family in tenancy\"
  ]" > statements.json
fi

# 检查命令执行结果
function check() {
  if echo "$1" | grep -q "ServiceError"; then
    err_msg=$(echo "$1" | sed -n 's/.*"message": "\(.*\)",/\1/p')
    echo -e "${RED}命令执行失败：$err_msg${RESET}"
    if [ "$ignore_error" == "0" ]; then
      exit 1
    fi
  else
    echo -e "${GREEN}$2${RESET}"
  fi
}

# 获取租户OCID
compartment_id=$(oci iam availability-domain list --query 'data[0]."compartment-id"' --raw-output)
echo -e "${GREEN}租户OCID: $compartment_id ${RESET}"

# 创建组
group_result=$(oci iam group create --compartment-id $compartment_id --name $group_name --description $group_des 2>&1)
check "$group_result" "组创建成功"
group_id=$(echo $group_result | jq -r '.data.id')

# 创建策略
policy_result=$(oci iam policy create --compartment-id $compartment_id --description $policy_des --name $policy_name --statements $policy_file  2>&1)
check "$policy_result" "策略创建成功"

# 创建用户
if [ "$user_email" == "" ]; then
  user_result=$(oci iam user create --name $user_name --description $user_des --compartment-id $compartment_id  2>&1)
else
  user_result=$(oci iam user create --name $user_name --description $user_des --compartment-id $compartment_id --email $user_email  2>&1)
fi
check "$user_result" "用户创建成功"
user_id=$(echo $user_result | jq -r '.data.id')

# 将用户添加到组
add_result=$(oci iam group add-user --group-id $group_id --user-id $user_id  2>&1)
check "$add_result" "用户添加到组成功\n\n后续可手动在用户 $user_name 中添加 API密钥 (无需登录该用户)"
